@@ -1,14 +1,14 @@
-import pytest
-
 from birdbrain_tasks import BirdbrainTasks
 
+
 async def method_1(p):
     for i in range(40):
         print("method_1 running", p, i)
 
         await BirdbrainTasks.yield_task()
 
-    return("method_1_return")
+    return "method_1_return"
+
 
 async def method_2(p):
     for i in range(20):
@@ -16,7 +16,8 @@ async def method_2(p):
 
         await BirdbrainTasks.yield_task()
 
-    return(2)
+    return 2
+
 
 async def method_3():
     for i in range(30):
@@ -24,6 +25,7 @@ async def method_3():
 
         await BirdbrainTasks.yield_task()
 
+
 def test_tasks_with_wait():
     tasks = BirdbrainTasks()
 
